==> v2.2.0.zip: pdf_tech_back_end/pdf-tech-core/src/main/java/cn/kdan/pdf/tech/core/constant/AuthConstant.java <==
package cn.kdan.pdf.tech.core.constant;

/**
 * @author tangxiangan
 */
public interface AuthConstant {

    int EXCEPTION_CODE_IMAGE_CODE_ERROR = 301;
    String EXCEPTION_MSG_IMAGE_CODE_ERROR = "图形验证码错误";


    String SUCCESS_MSG_CODE_SEND = "验证码发送成功";

    String SUCCESS_MSG_Register = "注册成功";

    String SUCCESS_MSG_CODE_SEND_MAIL = "邮件发送成功";
    String EXCEPTION_MSG_CODE_SEND_ERROR = "验证码发送失败";
    String EXCEPTION_MAIL_CODE_SEND_ERROR = "邮件发送失败";
    String EXCEPTION_MSG_CODE_ERROR = "验证码输入错误";

    String EXCEPTION_MSG_RESET_PASSWORD_ERROR = "重置密码链接已过期";

    String EXCEPTION_MSG_EMAIL_CODE_ERROR = "邮箱验证码错误";

    String EXCEPTION_MSG_USER_VERIFY_ERROR = "身份认证失败";

    String VERIFY_CODE_CHECK_SUCCESS = "验证通过";

    String EXCEPTION_MSG_CODE_ACTION_ERROR = "操作类型错误";
    String EXCEPTION_MSG_CODE_TYPE_ERROR = "发送方式错误";

    int EXCEPTION_CODE_USER_NOT_FOUND = 302;
    String EXCEPTION_MSG_USER_NOT_FOUND = "Please Create your Account first";


    int EXCEPTION_CODE_USER_PASSWORD_ERROR = 306;
    String EXCEPTION_MSG_USER_PASSWORD_ERROR = "账号或者密码错误";

    int EXCEPTION_CODE_TOKEN_IS_INVALID = 310;
    String EXCEPTION_MSG_TOKEN_IS_INVALID = "无效的token或者token已过期";

    int EXCEPTION_CODE_USER_NOT_LOGIN = 313;
    String EXCEPTION_MSG_USER_NOT_LOGIN = "用户没有登录，请登录后再访问";


    String GET_AUTHORIZE_CODE_SUCCESS = "获取授权码成功";
    String EXCEPTION_MSG_PLEASE_ADD_AUTH_CONFIG = "请添加OAuth2登录配置";

    int EXCEPTION_CODE_GET_TOKEN_FAIL = 315;
    String EXCEPTION_MSG_GET_TOKEN_FAIL = "获取token失败";
    String SESSION_ = "session_";
    String DEFAULT_REDIRECT_URI = "https://127.0.0.1";

    String VERIFY_CODE_KEY = "pdf_tech_verifyCode_";

    String VERIFY_CODE_TIME_OUT = "pdf_tech_verifyCode_timeout_";

    Long VERIFY_CODE_KEY_EXPIRE_TIME = 15 * 60L;

    /**
     * 邀请链接过期时间72小时
     */
    Long INVITE_VERIFY_CODE_KEY_EXPIRE_TIME = 72 * 60 * 60L;

    Long VERIFY_CODE_KEY_RESEND_TIME = 60L;

    String VERIFY_CODE_SEND_TOO_QUICKLY = "您的操作过于频繁，请稍后再试";

}

==> v3.0.1.zip: pdf_tech_back_end/pdf-tech-core/src/main/java/cn/kdan/pdf/tech/core/constant/AuthConstant.java <==
package cn.kdan.pdf.tech.core.constant;

/**
 * @author tangxiangan
 */
public interface AuthConstant {

    String EXCEPTION_MSG_IMAGE_CODE_ERROR = "图形验证码错误";


    String SUCCESS_MSG_CODE_SEND = "验证码发送成功";

    String SUCCESS_MSG_Register = "注册成功";

    String SUCCESS_MSG_CODE_SEND_MAIL = "邮件发送成功";
    String EXCEPTION_MSG_CODE_SEND_ERROR = "验证码发送失败";
    String EXCEPTION_MAIL_CODE_SEND_ERROR = "邮件发送失败";

    String EXCEPTION_MSG_CODE_ACTION_ERROR = "操作类型错误";
    String EXCEPTION_MSG_CODE_TYPE_ERROR = "发送方式错误";

    int EXCEPTION_CODE_USER_NOT_FOUND = 302;
    String EXCEPTION_MSG_USER_NOT_FOUND = "Please Create your Account first";

    int EXCEPTION_CODE_USER_NOT_ROLE = 316;
    String EXCEPTION_MSG_USER_NOT_ROLE = "Account doesn't have Permission to log in. Please contact your super admin to get the permission.";


    int EXCEPTION_CODE_USER_PASSWORD_ERROR = 306;
    String EXCEPTION_MSG_USER_PASSWORD_ERROR = "账号或者密码错误";

    int EXCEPTION_CODE_TOKEN_IS_INVALID = 310;
    String EXCEPTION_MSG_TOKEN_IS_INVALID = "无效的token或者token已过期";

    int EXCEPTION_CODE_USER_NOT_LOGIN = 313;
    String EXCEPTION_MSG_USER_NOT_LOGIN = "用户没有登录，请登录后再访问";


    String GET_AUTHORIZE_CODE_SUCCESS = "获取授权码成功";
    String EXCEPTION_MSG_PLEASE_ADD_AUTH_CONFIG = "请添加OAuth2登录配置";

    int EXCEPTION_CODE_GET_TOKEN_FAIL = 315;
    String EXCEPTION_MSG_GET_TOKEN_FAIL = "获取token失败";
    String SESSION_ = "session_";
    String DEFAULT_REDIRECT_URI = "https://127.0.0.1";

    String VERIFY_CODE_KEY = "pdf_tech_verifyCode_";

    String VERIFY_CODE_TIME_OUT = "pdf_tech_verifyCode_timeout_";

    Long VERIFY_CODE_KEY_EXPIRE_TIME = 15 * 60L;

    /**
     * 邀请链接过期时间72小时
     */
    Long INVITE_VERIFY_CODE_KEY_EXPIRE_TIME = 72 * 60 * 60L;

    Long VERIFY_CODE_KEY_RESEND_TIME = 60L;

    String VERIFY_CODE_SEND_TOO_QUICKLY = "您的操作过于频繁，请稍后再试";

}
